@@ -791,7 +791,7 @@ void App_Glom::stop_self_hosting_of_document_database()
     if(!connection_pool)
       return;
 
-    connection_pool->stop_self_hosting();
+    connection_pool->stop_self_hosting(this);
   }
 }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
@@ -945,7 +945,7 @@ bool App_Glom::on_document_load()
 
           if(!is_example) /* It will be started later, after we have asked for the initial db name/title and created the files.*/
           {
-            const bool test = connection_pool->start_self_hosting(); //Stopped in on_menu_file_close().
+            const bool test = connection_pool->start_self_hosting(this); //Stopped in on_menu_file_close().
             if(!test)
               return false;
           }
@@ -1629,6 +1629,12 @@ void App_Glom::fill_menu_tables()
   if(m_menu_tables_ui_merge_id)
     m_refUIManager->remove_ui(m_menu_tables_ui_merge_id);
 
+  if(m_refNavTablesActionGroup)
+  {
+    m_refUIManager->remove_action_group(m_refNavTablesActionGroup);
+    m_refNavTablesActionGroup.clear();
+  }
+
   m_refNavTablesActionGroup = Gtk::ActionGroup::create("NavTablesActions");
 
   Glib::ustring ui_description =
@@ -1712,6 +1718,12 @@ void App_Glom::fill_menu_reports(const Glib::ustring& table_name)
   if(m_menu_reports_ui_merge_id)
     m_refUIManager->remove_ui(m_menu_reports_ui_merge_id);
 
+  if(m_refNavReportsActionGroup)
+  {
+    m_refUIManager->remove_action_group(m_refNavReportsActionGroup);
+    m_refNavReportsActionGroup.clear();
+  }
+
   m_refNavReportsActionGroup = Gtk::ActionGroup::create("NavReportsActions");
 
   Glib::ustring ui_description =
