@@ -29,6 +29,8 @@
 #include <vector>
 #include <map>
 
+namespace Glom
+{
 
 class AddDelColumnInfo
 {
@@ -230,6 +232,8 @@ protected:
   virtual void on_treeview_cell_edited(const Glib::ustring& path_string, const Glib::ustring& new_text, int model_column_index);
   virtual void on_treeview_cell_edited_bool(const Glib::ustring& path_string, int model_column_index);
 
+  void on_treeview_cell_editing_started(Gtk::CellEditable* editable, const Glib::ustring& path, int model_column_index);
+
   virtual bool on_treeview_column_drop(Gtk::TreeView* treeview, Gtk::TreeViewColumn* column, Gtk::TreeViewColumn* prev_column, Gtk::TreeViewColumn* next_column);
   virtual void on_treeview_columns_changed();
 
@@ -328,7 +332,7 @@ guint AddDel::treeview_append_column(const Glib::ustring& title, const Gtk::Tree
   return treeview_append_column(title, *pCellRenderer, column, column_id);
 }
 
-
+} //namespace Glom
 
 
 #endif //ADDDEL_H
